pub struct LspServerConfig {
pub key: &'static str,
pub env_vars: &'static [&'static str],
pub default_command: &'static [&'static str],
}Expand description
Configuration for an LSP server.
Defines how to locate and run the language server.
Examples
use iced_code_editor::lsp_server_config;
if let Some(config) = lsp_server_config("rust-analyzer") {
println!("key: {}", config.key);
}Fields
key: &'static strUnique identifier for this server configuration
env_vars: &'static [&'static str]Environment variables to check for custom server paths (checked in order)
default_command: &'static [&'static str]Default command and arguments to run the server